#include <bits/stdc++.h>
using namespace std;

/**
 * Author: Tikhon Evteev/Vsevolod Nagibin
 * Description: Flow algorithm with complexity $O(VE\log U)$ where $U = \max |\text{cap}|$.
 * $O(\min(E^{1/2}, V^{2/3})E)$ if $U = 1$; $O(\sqrt{V}E)$ for bipartite matching.
 */
#pragma once

// Warning: int flow!
const int INF = 1e9;

struct Edge {
  int from, to;
  int flow;
  int cap;
  Edge(int from, int to, int flow, int cap): from(from), to(to), flow(flow), cap(cap) {}
};

struct DinicFlow {
  vector<Edge> edges;
  vector<vector<int>> G;
  vector<int> last_edge;
  vector<int> dist;
  int N;
  int s, t;

  DinicFlow(int N, int s, int t): edges(), G(N), last_edge(N, 0), dist(N, 0), N(N), s(s), t(t) {}

  void add_undir_edge(int from, int to, int cap) {
    G[from].emplace_back(edges.size());
    edges.emplace_back(from, to, 0, cap);
    G[to].emplace_back(edges.size());
    edges.emplace_back(to, from, 0, cap);
  }

  void add_dir_edge(int from, int to, int cap) {
    G[from].emplace_back(edges.size());
    edges.emplace_back(from, to, 0, cap);
    G[to].emplace_back(edges.size());
    edges.emplace_back(to, from, 0, 0);
  }

  int dfs(int v, int mf) {
    if (v == t)
      return mf;
    int res = 0;
    for (; last_edge[v] < (int)G[v].size(); ++last_edge[v]) {
      int i = G[v][last_edge[v]];
      if (dist[edges[i].to] != dist[v] + 1)
        continue;
      if (edges[i].cap <= edges[i].flow)
        continue;
      int cur = dfs(edges[i].to, min(mf - res, edges[i].cap - edges[i].flow));
      if (cur == 0)
        continue;
      res += cur;
      edges[i].flow += cur;
      edges[i ^ 1].flow -= cur;
      if (edges[i].cap > edges[i].flow || res == mf)
        return res;
    }
    return res;
  }

  int flow() {
    while (true) {
      dist.assign(N, N);
      deque<int> Q;
      dist[s] = 0;
      Q.emplace_back(s);
      while (!Q.empty()) {
        int v = Q.front();
        Q.pop_front();
        for (int i : G[v]) {
          if (edges[i].cap > edges[i].flow && dist[edges[i].to] > dist[v] + 1) {
            dist[edges[i].to] = dist[v] + 1;
            Q.emplace_back(edges[i].to);
          }
        }
      }
      if (dist[t] == N)
        break;
      fill(last_edge.begin(), last_edge.end(), 0);
      while (dfs(s, INF));
    }
    int res = 0;
    for (int i : G[s])
      res += edges[i].flow;
    return res;
  }

  vector<int> used;

  bool check_dfs(int v, int to) {
    used[v] = true;
    if (v == to) return true;
    for (int e : G[v]) {
      if (edges[e].cap == edges[e].flow) continue;
      int u = edges[e].to;
      if (!used[u] && check_dfs(u, to)) return true;
    }
    return false;
  }

  bool check(int u, int v) {
    used = vector<int>(N, 0);
    return check_dfs(u, v);
  }
};

const int MAXN = 2e3 + 100;
int p[2][MAXN];
int id[2][MAXN];

void solve_() {
  int n;
  cin >> n;
  for (int i = 0; i < 2; ++i) {
    for (int j = 0; j < n; ++j) {
      cin >> p[i][j];
      --p[i][j];
      id[i][p[i][j]] = j;
    }
  }
  int k;
  cin >> k;
  DinicFlow flow(2 * n + 2 * k + 2, 2 * n + 2 * k, 2 * n + 2 * k + 1);
  for (int i = 0; i < n; ++i) {
    flow.add_dir_edge(i, n + i, 1);
  }
  bool is_inconsistent = false;
  for (int i = 0; i < 2; ++i) {
    vector<int> ord;
    ord.resize(k);
    int len = 0;
    int lst = -1;
    int ptr = 0;
    for (int j = 0; j < k; ++j) {
      cin >> ord[j];
      if (ord[j] != -1) --ord[j];
      if (ord[j] == -1) {
        ++len;
      } else {
        if (len != 0) {
          int v = 2 * n + k * i + ptr;
          if (i == 0) {
            flow.add_dir_edge(flow.s, v, len);
          } else {
            flow.add_dir_edge(v, flow.t, len);
          }
          for (int pos = lst + 1; pos < id[i][ord[j]]; ++pos) {
            int from = v;
            int to = i * n + p[i][pos];
            if (i) swap(from, to);
            flow.add_dir_edge(from, to, 1);
          }
          ++ptr;
          len = 0;
        }
        int v = 2 * n + k * i + ptr;
        if (i == 0) {
          flow.add_dir_edge(flow.s, v, 1);
          flow.add_dir_edge(v, ord[j], 1);
        } else {
          flow.add_dir_edge(n + ord[j], v, 1);
          flow.add_dir_edge(v, flow.t, 1);
        }
        ++ptr;
        if (id[i][ord[j]] < lst) {
          is_inconsistent = true;
        }
        lst = id[i][ord[j]];
      }
    }
    if (len != 0) {
      int v = 2 * n + k * i + ptr;
      if (i == 0) {
        flow.add_dir_edge(flow.s, v, len);
      } else {
        flow.add_dir_edge(v, flow.t, len);
      }
      for (int pos = lst + 1; pos < n; ++pos) {
        int from = v;
        int to = i * n + p[i][pos];
        if (i) swap(from, to);
        flow.add_dir_edge(from, to, 1);
      }
      ++ptr;
    }
  }
  int res = flow.flow();
  if (res < k || is_inconsistent) {
    cout << "Inconsistent\n";
    return;
  }
  string ans(n, '?');
  for (int i = 0; i < n; ++i) {
    if (!flow.check(i, i + n)) {
      ans[i] = 'Y';
    }
    if (!flow.check(i + n, i)) {
      ans[i] = 'N';
    }
  }
  cout << ans << "\n";
}

#define MULTITEST

signed main() {
#ifdef LOCAL
    freopen("../input.txt", "r", stdin);
    freopen("../output.txt", "w", stdout);
#else
    ios_base::sync_with_stdio(false);
    cin.tie(0);
#endif
    int tst = 1;
#ifdef MULTITEST
    cin >> tst;
#endif // MULTITEST
    while (tst--) {
        solve_();
    }
    return 0;
}