#include <iostream>
#include <vector>
#include <array>
#include <algorithm>

using namespace std;

#define all(x) (x).begin(), (x).end()
using ll = long long;
using vi = vector<int>;
using vl = vector<ll>;
using pll = array<ll, 2>;

pll add(pll a, pll b) {
    return pll{a[0] + b[0], a[1] + b[1]};
}

pll sub(pll a, pll b) {
    return pll{a[0] - b[0], a[1] - b[1]};
}

struct vec {
    pll x, y;

    vec(pll x = {0,0}, pll y = {0,0}) : x(x), y(y) {}
    vec operator+ (vec v) const { return vec(add(x, v.x), add(y, v.y)); }
    vec operator- (vec v) const { return vec(sub(x, v.x), sub(y, v.y)); }
    vec operator* (ll a) const { return vec(pll{x[0] * a, x[1] * a}, pll{y[0] * a, y[1] * a}); }
    bool operator< (vec v) const {
        return tie(x, y) < tie(v.x, v.y);
    }bool operator== (vec v) const {
        return tie(x, y) == tie(v.x, v.y);
    }
};

using segment = array<vec, 2>;

segment toseg(vec a, vec b) {
    if (b < a) return {b, a};
    return {a, b};
}

bool match(const vector<segment> & a, const vector<segment> & b, vec d) {
    int n = a.size();
    vector<segment> c;
    for (int i = 0; i < n; ++i) {
        auto [fi, se] = b[i];
        c.push_back(toseg(fi + d, se + d));
    }
    sort(all(c));
    return a == c;
}

bool check(const vector<segment> & a, const vector<segment> & b) {
    int n = a.size();
    for (int i = 0; i < n; ++i) {
        if (match(a, b, a[i][0] - b[0][0])) return true;
        if (match(a, b, a[i][1] - b[0][0])) return true;
    }
    return false;
}

int main() {
    ios::sync_with_stdio(false);
    cin.tie(0);

    vector<vec> v;
    v.emplace_back(pll{1, 0}, pll{0, 0});
    v.emplace_back(pll{0, 1}, pll{0, 1});

    v.emplace_back(pll{0, 0}, pll{1, 0});
    v.emplace_back(pll{0, -1}, pll{0, 1});

    v.emplace_back(pll{-1, 0}, pll{0, 0});
    v.emplace_back(pll{0, -1}, pll{0, -1});

    v.emplace_back(pll{0, 0}, pll{-1, 0});
    v.emplace_back(pll{0, 1}, pll{0, -1});

    int n;
    cin >> n;
    string op(n, '.');
    vl dx(n);
    for (int i = 0; i < n; ++i) {
        string s;
        cin >> s >> dx[i];
        op[i] = s[0];
    }
    vector<vector<segment> > cand(8);
    for (int i = 0; i < 8; ++i) {
        int curdir = i;
        vec cur;
        for (int j = 0; j < n; ++j) {
            if (op[j] == 'm') {
                cur = cur + v[curdir] * dx[j];
            } else if (op[j] == 'r') {
                curdir += dx[j] / 45;
                curdir %= 8;
            } else {
                vec nxt = cur + v[curdir] * dx[j];
                cand[i].push_back(toseg(cur, nxt));
                cur = nxt;
            }
        }
    }
    sort(all(cand[0]));
    for (int i = 7; i >= 0; --i) {
        if (check(cand[0], cand[i])) {
            int ans = 45 * (8 - i);
            cout << ans << endl;
            return 0;
        }
    }
}