#include <bits/stdc++.h>
using namespace std;

using ll = long long;
using ld = long double;

#define all(a) begin(a), end(a)
#define len(a) int((a).size())
#define rep(i, n) for (int i = 0; i < (n); i++)

mt19937 rnd;

const int inf = 1e9 + 20;

struct max_flow {
    struct edge {
        int to, rev, flow, cap;
    };

    int n, s, t;
    vector<vector<edge>> g;

    max_flow(int n = 0) : n(n), g(n) {}

    int new_vertex() {
        g.push_back({});
        n++;
        return n - 1;
    }

    int add_edge(int v, int u, int cap) {
        assert(v != u);
        assert(0 <= v && v < len(g));
        assert(0 <= u && u < n);
        g[v].push_back({u, len(g[u]), 0, cap});
        g[u].push_back({v, len(g[v]) - 1, 0, 0});
        return len(g[v]) - 1;
    }

    vector<int> dist, ptr;

    bool bfs() {
        dist.assign(n, n);
        queue<int> que;
        que.push(s);
        dist[s] = 0;
        while (!que.empty()) {
            auto v = que.front();
            que.pop();
            for (const auto &[u, rev, flow, cap] : g[v]) {
                if (flow < cap && dist[u] > dist[v] + 1) {
                    dist[u] = dist[v] + 1;
                    que.push(u);
                }
            }
        }
        return dist[t] != n;
    }

    int dfs(int v, int f) {
        if (v == t) {
            return f;
        }
        for (; ptr[v] < len(g[v]); ptr[v]++) {
            auto &[u, rev, flow, cap] = g[v][ptr[v]];
            if (dist[u] != dist[v] + 1 || flow == cap) {
                continue;
            }

            int res = dfs(u, min(f, cap - flow));
            if (res > 0) {
                flow += res;
                g[u][rev].flow -= res;
                return res;
            }
        }
        return 0;
    }

    int solve(int source_, int sink_) {
        s = source_;
        t = sink_;

        int ans = 0;
        while (bfs()) {
            ptr.assign(n, 0);
            while (true) {
                int res = dfs(s, inf);
                if (res == 0) {
                    break;
                }
                ans += res;
            }
        }
        return ans;
    }

    vector<bool> used;
    int dest;
    
    bool dfs2(int v) {
        if (v == dest) {
            return true;
        }
        used[v] = true;
        for (auto [u, rev, flow, cap] : g[v]) {
            if (used[u] || flow == cap) {
                continue;
            }
            if (dfs2(u)) {
                return true;
            }
        }
        return false;
    }

    bool check(int from, int to) {
        used.assign(n, false);
        dest = to;
        return dfs2(from);
    }
};

void solve() {
    int n;
    cin >> n;
    vector<int> p1(n);
    for (auto &x : p1) {
        cin >> x;
        x--;
    }
    vector<int> p2(n);
    for (auto &x : p2) {
        cin >> x;
        x--;
    }

    int k;
    cin >> k;
    vector<bool> know(n);

    vector<int> first(k);
    for (auto &x : first) {
        cin >> x;
        if (x == -1) {
            continue;
        }
        x--;
        know[x] = true;
    }

    vector<int> second(k);
    for (auto &x : second) {
        cin >> x;
        if (x == -1) {
            continue;
        }
        x--;
        know[x] = true;
    }

    max_flow mf(0);
    const int source = mf.new_vertex();
    const int sink = mf.new_vertex();

    bool ok = true;

    auto build = [&](vector<int> a, vector<int> ord, bool first) {
        vector<int> where(n, -1);

        vector<int> id(n + 2, -2);
        id[0] = -1;
        id[n + 1] = k;
        for (int i = 0; i < k; i++) {
            if (a[i] != -1) {
                id[int(find(all(ord), a[i]) - ord.begin()) + 1] = i;

                int v = mf.new_vertex();
                where[a[i]] = v;
                if (first) {
                    mf.add_edge(source, v, 1);
                } else {
                    mf.add_edge(v, sink, 1);
                }
            }
        }

        for (int l = 0; l + 1 < len(id);) {
            int r = l + 1;
            while (id[r] == -2) {
                r++;
            }

            int tot = id[r] - id[l] - 1;
            if (tot < 0) {
                ok = false;
                break;
            }

            int v = mf.new_vertex();
            for (int i = l + 1; i < r; i++) {
                where[ord[i - 1]] = v;
                if (know[ord[i - 1]]) {
                    if (first) {
                        mf.add_edge(source, v, 1);
                    } else {
                        mf.add_edge(v, sink, 1);
                    }
                    tot--;
                }
            }

            if (tot > 0) {
                if (first) {
                    mf.add_edge(source, v, tot);
                } else {
                    mf.add_edge(v, sink, tot);
                }
            }
            if (tot < 0) {
                ok = false;
                break;
            }

            l = r;
        }
        return where;
    };

    auto where1 = build(first, p1, true);
    auto where2 = build(second, p2, false);

    if (!ok) {
        cout << "Inconsistent\n";
        return;
    }

    vector<int> my_edge(n);
    for (int i = 0; i < n; i++) {
        my_edge[i] = mf.add_edge(where1[i], where2[i], 1);
    }

    int f = mf.solve(source, sink);
    if (f != k) {
        cout << "Inconsistent\n";
        return;
    }

    string ans(n, '?');
    for (int i = 0; i < n; i++) {
        if (know[i]) {
            ans[i] = 'Y';
            continue;
        }

        auto &e = mf.g[where1[i]][my_edge[i]];
        if (e.flow == 0) {
            ans[i] = 'N';
            if (mf.check(where2[i], where1[i])) {
                ans[i] = '?';
            }
        } else {
            ans[i] = 'Y';
            if (mf.check(where1[i], where2[i])) {
                ans[i] = '?';
            }
        }
    }
    cout << ans << '\n';
}

signed main() {
    cin.tie(nullptr)->sync_with_stdio(false);

    int t;
    cin >> t;
    while (t--) {
        solve();
    }

    return 0;
}
