#pragma GCC optimize("O3")

#include <bits/stdc++.h>

using namespace std;

#define ll long long
#define ld long double
#define x first
#define y second

typedef pair<ld, ld> point;

struct line {
    ll angle;
    point a;
    point b;
};

const ld EPS = 0.000000000001;

class UDS {
    vector<int> uds;
    vector<int> sizes;
    int count = 0;
public:
    UDS(int n) {
        uds = vector<int>(n);
        sizes = vector<int>(n, 0);
        for (int i = 0; i < n; ++i) uds[i] = i;
        count = n;
    }

    int head(int u) {
        if (uds[u] == u) return u;
        return uds[u] = head(uds[u]);
    }

    void unite(int a, int b) {
        a = head(a);
        b = head(b);
        if (a == b) return;
        count--;
        if (sizes[a] < sizes[b]) swap(a, b);
        uds[b] = a;
        if (sizes[a] == sizes[b]) ++sizes[a];
    }

    int get_count() {
        return count;
    }
};

ld root2 = sqrt(2);

line move(point from, ll angle, ld length) {
    switch (angle%360) {
        case 0:
            return line(angle, from, {from.x, from.y+length});
        case 45:
            return line(angle, from, {from.x-length/root2, from.y+length/root2});
        case 90:
            return line(angle, from, {from.x-length, from.y});
        case 135:
            return line(angle, from, {from.x-length/root2, from.y-length/root2});
        case 180:
            return line(angle, from, {from.x, from.y-length});
        case 225:
            return line(angle, from, {from.x+length/root2, from.y-length/root2});
        case 270:
            return line(angle, from, {from.x+length, from.y});
        default:
            return line(angle, from, {from.x+length/root2, from.y+length/root2});
    }
}

typedef vector<line> figure;

struct command {
    ll t;
    ll val;
};

pair<point, bool> max_p(point a, point b) {
    if (a.y < b.y || (a.y == b.y && a.x < b.x)) return {b, true};
    return {a, false};
}

pair<point, bool> min_p(point a, point b) {
    if (a.y > b.y || (a.y == b.y && a.x > b.x)) return {b, true};
    return {a, false};
}


bool operator<(point &a, point &b) {
    if (abs(a.y - b.y) < EPS) {
        return a.x < b.x;
    }
    return a.y < b.y;
}

bool operator==(point &a, point &b) {
    return abs(a.x - b.x) < EPS && abs(a.y - b.y) < EPS;
}

bool comp(const line & a, const line & b) {
    if (a.a == b.a) {
        return a.b < b.b;
    }
    return a.a < b.a;
}

figure compress(figure & f) {
    UDS uds(f.size());
    map<pair<point, ll>, vector<int>> line_by_dots;
    for (int i = 0; i < f.size(); ++i) {
        line_by_dots[{f[i].a, f[i].angle % 180}].push_back(i);
        line_by_dots[{f[i].b, f[i].angle % 180}].push_back(i);
    }
    point cur_point;
    ll angle;
    vector<int> indexes;
    for (int i = 0; i < f.size(); ++i) {
        vector<int> lines_a = line_by_dots[{f[i].a, f[i].angle%180}];
        vector<int> lines_b = line_by_dots[{f[i].b, f[i].angle%180}];

        for (int j : lines_a) uds.unite(i, j);
        for (int j : lines_b) uds.unite(i, j);
    }
    // Получаем сжатую версию
    vector<bool> used(uds.get_count(), false);
    figure ret_fig(uds.get_count());
    for (int i = 0; i < f.size(); ++i) {
        if (!used[uds.head(i)]) {
            ret_fig[uds.head(i)].a = min_p(f[i].a, f[i].b).first;
            ret_fig[uds.head(i)].b = max_p(f[i].a, f[i].b).first;
        } else {
            ret_fig[uds.head(i)].a = min_p(min_p(f[i].a, f[i].b).first, ret_fig[uds.head(i)].a).first;
            ret_fig[uds.head(i)].b = max_p(max_p(f[i].a, f[i].b).first, ret_fig[uds.head(i)].b).first;
        }
    }
    sort(ret_fig.begin(), ret_fig.end(), comp);
    return ret_fig;
}


void inline solve() {
    int n;
    char s[20];
    cin >> n;
    vector<command> commands;
    ll len, com;
    for (int i = 0; i < n; ++i) {
        cin >> s >> len;
        if (s[0] == 'd') com = 0;
        else if (s[0] == 'r') com = 1;
        else com = 2;
        if (!commands.empty() && commands.back().t == com) {
            commands.back().val += len;
        } else {
            commands.push_back(command(com, len));
        }
    }

    figure zero_figure;
    ll angle = 0;
    point cur = {0, 0};
    line l;
    for (command & c : commands) {
        switch (c.t) {
            case 0: // draw
                l = move(cur, angle, c.val);
                zero_figure.push_back(l);
                cur = l.b;
                break;
            case 1: // rotate
                angle = (angle + c.val)%360;
                break;
            case 2: // move
                l = move(cur, angle, c.val);
                cur = l.b;
                break;
        }
    }
    // Стакаем первый
    zero_figure = compress(zero_figure);
//    point zero_left_up = zero_figure[0].a;
//    int zero_max_point_i = 0;
//    for (int i = 0; i < zero_figure.size(); ++i) {
//        tie(zero_left_up, zero_max_point_i) = max_p(zero_left_up, zero_figure[i].a);
//    }
    // Перебор
    for (int i = 45; i < 360; i+=45) {
        figure cur_figure;
        angle = i;
        cur = {0, 0};
        for (command & c : commands) {
            switch (c.t) {
                case 0: // draw
                    l = move(cur, angle, c.val);
                    cur_figure.push_back(l);
                    cur = l.b;
                    break;
                case 1: // rotate
                    angle = (angle + c.val)%360;
                    break;
                case 2: // move
                    l = move(cur, angle, c.val);
                    cur = l.b;
                    break;
            }
        }
        // Сжимаем
        cur_figure = compress(cur_figure);
        // Сдвигаем
//        point cur_left_up = cur_figure[0].a;
//        int cur_max_point_i = 0;
//        for (int j = 0; j < cur_figure.size(); ++j) {
//            tie(cur_left_up, cur_max_point_i) = max_p(cur_left_up, cur_figure[j].a);
//        }
        ld x_delta = cur_figure[0].a.x - zero_figure[0].a.x;
        ld y_delta = cur_figure[0].a.y -  zero_figure[0].a.y;
        // Проверяем
        if (zero_figure.size() != cur_figure.size()) continue;
        bool flag = true;
        for (int j = 0; j < cur_figure.size() && flag; ++j) {
            flag = flag && (abs(zero_figure[j].a.x + x_delta - cur_figure[j].a.x) < EPS);
            flag = flag && (abs(zero_figure[j].a.y + y_delta - cur_figure[j].a.y) < EPS);
            flag = flag && (abs(zero_figure[j].b.x + x_delta - cur_figure[j].b.x) < EPS);
            flag = flag && (abs(zero_figure[j].b.y + y_delta - cur_figure[j].b.y) < EPS);
        }
        if (flag) {
            cout << i << '\n';
            return;
        }
    }
    cout << 360 << '\n';
}

int main() {
    ios_base::sync_with_stdio(false);
    cin.tie(NULL);
    cout.tie(NULL);

    int tests = 1;
//    cin >> tests;
    while (tests--) {
        solve();
    }

    return 0;
}

