#include<iostream>
#include<vector>
#include<map>
#include<set>
#include<algorithm>
#include<cstdint>
#include<bitset>
#include<string>

using namespace std;

#define int long long
using ull = uint64_t;

const ull MAX_DIST = 1e14;
const ull MAX_LOST = 400009;

vector<vector<pair<ull, ull>>> adjacent, rev_adjacent;
vector<ull> lost_distance, ort_distance;
bitset<400000> orthanc_reachable;
vector<ull> incompetence_cache;
ull n, m;

template <class T>
ostream& operator<<(ostream& dst, const vector<T>& src) {
	for (auto& v : src) dst << v << ' ';
	return dst;
}
template <class U, class V>
ostream& operator<<(ostream& dst, const pair<U, V>& src) {
	return dst << '(' << (long long)(src.first) << ':' << (long long)(src.second) << ')';
}

void dfs_orthanc_r(ull v) {
	orthanc_reachable[v] = true;
	for (auto& [u,_] : rev_adjacent[v]) {
		if (!orthanc_reachable[u]) dfs_orthanc_r(u);
	}
}
void bfs_orthanc_lost() {
	lost_distance.assign(n, MAX_LOST);

	vector<bool> seen(n, false); seen.back() = true;
	vector<pair<ull, ull>> q_lost_vd;
	for (ull i = 0; i < n; i++) {
		if (orthanc_reachable[i]) continue;
		q_lost_vd.emplace_back(i, 0);
		seen[i] = true;
	}
	ull j = 0;
	while (j < q_lost_vd.size()) {
		auto [v, dist] = q_lost_vd[j];
		for (auto& [u,_] : rev_adjacent[v]) {
			if (seen[u]) continue;
			q_lost_vd.emplace_back(u, dist + 1);
			seen[u] = true;
		}
		lost_distance[v] = dist;
		j++;
	}
}
void dij_orthanc() {
	ort_distance.assign(n, MAX_DIST);
	ort_distance.back() = 0;

	set<pair<ull, ull>> q_vd; q_vd.insert(make_pair(0, n - 1));
	while (!q_vd.empty()) {
		auto [dist, v] = *q_vd.begin();
		q_vd.erase(q_vd.begin());

		for (auto& [u, ed] : rev_adjacent[v]) {
			ull u_dist = dist + ed;
			if (u_dist >= ort_distance[u]) continue;
			// improvement
			if (ort_distance[u] < MAX_DIST)
				q_vd.erase(q_vd.find(make_pair(ort_distance[u], u)));
			q_vd.insert(make_pair(u_dist, u));
			ort_distance[u] = u_dist;
		}
	}
}
ull dfs_best(ull u) {
	if (incompetence_cache[u] + 1) return incompetence_cache[u];

	ull our_incompetence = lost_distance[u];
	ull max_incompetence_out = 0;
	for (auto& [v, ed] : adjacent[u]) {
		if (ort_distance[v] == MAX_DIST) continue;
		if (ort_distance[u] != ort_distance[v] + ed) continue;

		max_incompetence_out = max(max_incompetence_out, dfs_best(v));
		if (max_incompetence_out >= our_incompetence) break;
	}
	return incompetence_cache[u] = min(our_incompetence, max_incompetence_out);
}

void solve() {
	cin >> n >> m;
	adjacent.resize(n); rev_adjacent.resize(n);

	for (ull i = 0; i < m; i++) {
		ull u, v, w; cin >> u >> v >> w; --u; --v;
		adjacent[u].emplace_back(v, w);
		rev_adjacent[v].emplace_back(u, w);
	}

	dfs_orthanc_r(n - 1);
	bfs_orthanc_lost();    // cout << "lost_distance: " << lost_distance << endl;
	dij_orthanc();         // cout << "ort_distance:  " << ort_distance << endl;
	incompetence_cache.assign(n, -1); incompetence_cache.back() = n + 1000;
	cout << (long long)min(n + 1ull, dfs_best(0)) - 1 << endl;
}

signed main() {
	ios::sync_with_stdio(false); cin.tie(0);
	int t = 1; // cin >> t;
	for (int i = 0; i < t; i++)solve();

	return 0;
}