#include <iostream>
#include <vector>
#include <algorithm>
#include <set>
using namespace std;

const bool SET = true;
const bool UNSET = false;

const int N = 1e5+7;

#define F first
#define S second
#define pb push_back

int n;
int unsetTrueI = -1;
int setTrueI = -1;
vector<pair<bool, bool>> ops; // set/unset, T/F
set<int> g[N];
set<int> gR[N];
bool connected[N] {};

void connect(int a, int b) {
    g[a].insert(b);
    gR[b].insert(a);
    connected[a] = true;
    connected[b] = true;
}

bool dfs(int i, int visited[]) {
    visited[i] = 1;
    for (int j : g[i]) {
        // cerr << "dfs" << i << "->" << j << ": " << visited[j] << endl;
        if (visited[j] == 1) {
            return true;
        }
        if (visited[j] == 0 && dfs(j, visited)) {
            return true;
        }
    }
    visited[i] = 2;
    return false;
}

bool findCycle() {
    int visited[N] {};
    for (int i = 0; i < n; ++i) {
        if (!visited[i]) {
            if (dfs(i, visited)) {
                return true;
            }
        }
    }
    return false;
}

void dfs2(int i, bool visited[], vector<int>& order) {
    visited[i] = true;
    for (int j : g[i]) {
        if (!visited[j]) {
            dfs2(j, visited, order);
        }
    }
    order.push_back(i);
}

vector<int> toposort() {
    vector<int> order;
    bool visited[N] {};
    for (int i = 0; i < n; ++i) {
        if (!visited[i]) {
            dfs2(i, visited, order);
        }
    }
    reverse(order.begin(), order.end());
    return order;
}

void connectUnsets(int v) {
    for (auto to : g[v]) {
        if (ops[to].F == UNSET && !ops[to].S && !g[to].count(setTrueI)) {
            connect(to, setTrueI);
            connectUnsets(to);
        }
    }
}

void connectUnsetsRev(int v) {
    for (auto to : gR[v]) {
        if (ops[to].F == UNSET && !ops[to].S && !gR[to].count(unsetTrueI)) {
            connect(unsetTrueI, to);
            connectUnsetsRev(to);
        }
    }
}

void solve() {
    cin >> n;
    string token;
    int cntTrue = 0;
    int cntSetFalse = 0;
    int cntUnsetTrue = 0;
    for (int i = 0; i < n; ++i) {
        cin >> token;
        bool op = token == "set" ? SET : UNSET;
        cin >> token;
        bool result = token == "true";
        ops.pb({op, result});
        cntTrue += result;
        if (op == SET && result) {
            setTrueI = i;
        }
        if (op == UNSET && result) {
            unsetTrueI = i;
        }
        cntSetFalse += op == SET && !result;
        cntUnsetTrue += op == UNSET && result;
    }
    int m, a, b;
    cin >> m;
    for (int i = 0; i < m; ++i) {
        cin >> a >> b;
        connect(--a, --b);
    }
    if (cntTrue == 0) {
        if (cntSetFalse) {
            cout << -1;
            return;
        }
        if (findCycle()) { // ( )
            cout << -1;
            return;
        }
        vector<int> order = toposort();
        for (int i : order) {
            cout << i + 1 << ' ';
        }
    }
    else if (cntTrue == 1) {
        if (cntUnsetTrue) {
            cout << -1;
            return;
        }
        for (int i = 0; i < n; ++i) {
            if (ops[i].F == UNSET) {
                connect(i, setTrueI);
            }
            if (ops[i].F == SET && !ops[i].S) {
                connect(setTrueI, i);
            }
        }
        // cout << *g[0].begin() << endl;
        // cout << *g[1].begin() << endl;
        if (findCycle()) {
            cout << -1;
            return;
        }
        vector<int> order = toposort();
        for (int i : order) {
            cout << i + 1 << ' ';
        }
    }
    else {
        if (setTrueI == -1 || unsetTrueI == -1) {
            cout << -1;
            return;
        }
        connect(setTrueI, unsetTrueI);
        for (int i = 0; i < n; ++i) {
            if (ops[i].F == SET && !ops[i].S) {
                connect(setTrueI, i);
                connect(i, unsetTrueI);
            }
        }
        for (int i = 0; i < n; ++i) {
            for (int j : g[i]) {
                if (ops[j].F == UNSET && !ops[j].S && ops[i].F == SET) {
                    connect(unsetTrueI, j);
                }
                if (ops[i].F == UNSET && !ops[i].S) {
                    if (ops[j].F == SET && !ops[j].S || ops[j].F == UNSET && ops[j].S) {
                        connect(i, setTrueI);
                    }
                }
            }
        }
        if (findCycle()) {
            cout << -1;
            return;
        }
        for (int i = 0; i < n; ++i) {
            if (ops[i].F == UNSET && !ops[i].S && g[i].count(setTrueI)) {
                connectUnsets(i);
            }
            if (ops[i].F == UNSET && !ops[i].S && gR[i].count(unsetTrueI)) {
                connectUnsetsRev(i);
            }
        }
        for (int i = 0; i < n; ++i) {
            if (!connected[i] && ops[i].F == UNSET && !ops[i].S) {
                connect(i, setTrueI);
            }
        }
        if (findCycle()) {
            cout << -1;
            return;
        }
        vector<int> order = toposort();
        for (int i : order) {
            cout << i + 1 << ' ';
        }
    }
}

int main() {
    cin.tie(nullptr);
    ios_base::sync_with_stdio(false);
    #ifdef LOCAL
    freopen("input.txt", "r", stdin);
    freopen("output1.txt", "w", stdout);
    #endif // LOCAL
    int t = 1;
    //cin >> t;
    for (int i = 0; i < t; ++i) {
        solve();
    }
    return 0;
}
