#define _CRT_SECURE_NO_WARNINGS

#include <iostream>
#include <iomanip>
#include <vector>
#include <cmath>
#include <algorithm>

// #define int long long
// #define double long double

using namespace std;

const int N = 1 << 12;

bool get(const vector<int>& mem, int ix) {
	int word = ix >> 4;
	int bit = ix & 15;
	return bool(mem[word] & (1 << bit));
}

void set(vector<int>& mem, int ix, bool val) {
	int word = ix >> 4;
	int bit = ix & 15;
	if (get(mem, ix) != val) {
		mem[word] ^= 1 << bit;
	}
}

int exec(vector<int> mem) {
	int ip = 0;
	while (ip < N - 2) {
		int a = mem[ip];
		int b = mem[ip + 1];
		bool val = get(mem, a);
		set(mem, b, val);
		ip = mem[ip + 2];
	}
	return mem[N - 1];
}

void print_digit(int x) {
	if (x < 10) {
		cout << char('0' + x);
	}
	else {
		cout << char('a' + (x - 10));
	}
}

void print(int x) {
	for (int i = 12; i >= 0; i -= 4) {
		int y = (x >> i) & 15;
		print_digit(y);
	}
	cout << '\n';
}

int get_index(int word, int bit) {
	return (word << 4) | bit;
}

int address_of(bool val) {
	if (val) {
		return get_index(0, 15);
	}
	else {
		return get_index(0, 0);
	}
}

void insert_killer(vector<int>& mem, int word) {
	mem[word] = address_of(0);
	mem[word + 1] = get_index(N - 1, 0);
	mem[word + 2] = N - 1;
}

void insert_jumper(vector<int>& mem, int word, int next) {
	mem[word] = 0;
	mem[word + 1] = 0;
	mem[word + 2] = next;
}

void insert_winner(vector<int>& mem, int word) {
	mem[word] = 4;
	mem[word + 1] = 0xfff0;
	mem[word + 2] = 0x0fff;
}

bool get_bit(int x, int bit) {
	return bool(x & (1 << bit));
}

void solve() {
	int x;
	cin >> x;

	vector<int> mem(N, 0);

	int ip = 0;
	for (int bit = 0; bit < 16; bit++) {
		mem[ip] = get_index(N - 1, bit);
		mem[ip + 1] = get_index(ip + 2, 7);
		mem[ip + 2] = ip + 3;

		if (get_bit(x, 0) == 0) {
			insert_jumper(mem, ip + 3, ip + 6);
			insert_killer(mem, ip + 3 + 128);
		}
		else {
			insert_killer(mem, ip + 3);
			insert_jumper(mem, ip + 3 + 128, ip + 6);
		}

		ip += 6;
	}

	insert_winner(mem, ip);
	ip += 3;

	for (int i = 0; i < 4000; i++) {
		print(mem[i]);
	}

	mem[N - 1] = x + 1;
	// cout << exec(mem);
}

signed main() {
#ifdef LOCAL
	freopen("input.txt", "r", stdin);
	freopen("output.txt", "w", stdout);
#else
	ios_base::sync_with_stdio(0);
	cin.tie(0);
#endif

	int t = 1;
	//cin >> t;
	while (t--) {
		solve();
	}

	return 0;
}