//#define _GLIBCXX_DEBUG
#include <bits/stdc++.h>

using namespace std;

#define pb push_back
#define all(a) a.begin(), a.end()

typedef long long ll;

ll gcd(ll a, ll b) {
    while (b != 0) {
        a %= b;
        swap(a, b);
    }
    return a;
}

struct frac {
    ll a = 0, b = 1;

    frac(ll x = 0) {
        a = x;
        b = 1;
    }

    frac(ll a1, ll b1) {
        a = a1;
        b = b1;
        if (b < 0) {
            a *= -1;
            b *= -1;
        }
        ll g = gcd(llabs(a), b);
        a /= g;
        b /= g;
    }
};

bool operator<(const frac &l, const frac &r) {
    return make_pair(l.a, l.b) < make_pair(r.a, r.b);
}

bool operator==(const frac &l, const frac &r) {
    return make_pair(l.a, l.b) == make_pair(r.a, r.b);
}

frac operator*(const frac &l, const frac &r) {
    return {l.a * r.a, l.b * r.b};
}

frac operator/(const frac &l, const frac &r) {
    return {l.a * r.b, l.b * r.a};
}

frac operator+(const frac &l, const frac &r) {
    return {l.a * r.b + l.b * r.a, l.b * r.b};
}

frac operator-(const frac &l, const frac &r) {
    return {l.a * r.b - l.b * r.a, l.b * r.b};
}

struct spec {
    frac a = 0, b = 0;
};

bool operator<(const spec &l, const spec &r) {
    return make_pair(l.a, l.b) < make_pair(r.a, r.b);
}

bool operator==(const spec &l, const spec &r) {
    return make_pair(l.a, l.b) == make_pair(r.a, r.b);
}

spec operator+(const spec &l, const spec &r) {
    return {l.a + r.a, l.b + r.b};
}

spec operator-(const spec &l, const spec &r) {
    return {l.a - r.a, l.b - r.b};
}

spec operator*(const spec &a, ll k) {
    return {a.a * k, a.b * k};
}

spec divsqrt2(spec s) {
    return {s.b, s.a / 2};
}

struct pt {
    spec x, y;
};

bool operator<(const pt &a, const pt &b) {
    return make_pair(a.x, a.y) < make_pair(b.x, b.y);
}

bool operator==(const pt &a, const pt &b) {
    return make_pair(a.x, a.y) == make_pair(b.x, b.y);
}

pt operator-(const pt &a, const pt &b) {
    return {a.x - b.x, a.y - b.y};
}

pt operator+(const pt &a, const pt &b) {
    return {a.x + b.x, a.y + b.y};
}

pt operator*(const pt &a, ll k) {
    return {a.x * k, a.y * k};
}

pt rot45(pt p) {
    return {divsqrt2(p.x - p.y), divsqrt2(p.x + p.y)};
}

bool cmp(const vector<pair<pt, pt>> &a1, const vector<pair<pt, pt>> &b, pt shift) {
    auto a = a1;
    for (auto &seg : a) {
        seg.first = seg.first + shift;
        seg.second = seg.second + shift;
        if (seg.first < seg.second) {
            swap(seg.first, seg.second);
        }
    }
    sort(all(a));
    for (int i = 0; i < (int)a.size(); ++i) {
        if (!(a[i] == b[i])) {
            return false;
        }
    }
    return true;
}

int main() {
#ifdef LOCAL
    freopen("in.txt", "r", stdin);
#endif
    ios::sync_with_stdio(false);
    cin.tie(0);
    int n;
    cin >> n;
    pt vec = {1, 0};
    pt pos = {0, 0};
    vector<vector<pair<pt, pt>>> bydir(4);
    {
        int dir = 0;
        while (n--) {
            string s;
            cin >> s;
            if (s == "rotate") {
                int a;
                cin >> a;
                a /= 45;
                dir = (dir + a) % 4;
                for (int i = 0; i < a; ++i) {
                    vec = rot45(vec);
                }
            }
            if (s == "draw") {
                ll d;
                cin >> d;
                pt new_pos = pos + vec * d;
                bydir[dir].push_back({pos, new_pos});
                pos = new_pos;
            }
            if (s == "move") {
                ll d;
                cin >> d;
                pos = pos + vec * d;
            }
        }
    }
    vector<pair<pt, pt>> segs;
    for (int dir = 0; dir < 4; ++dir) {
        vector<pt> pts;
        for (auto seg : bydir[dir]) {
            pts.push_back(seg.first);
            pts.push_back(seg.second);
        }
        sort(all(pts));
        pts.resize(unique(all(pts)) -  pts.begin());
        int sz = pts.size();
        vector<vector<int>> g(sz);
        for (auto seg : bydir[dir]) {
            int ind1 = lower_bound(pts.begin(), pts.end(), seg.first) - pts.begin();
            int ind2 = lower_bound(pts.begin(), pts.end(), seg.second) - pts.begin();
            assert(ind1 >= 0 && ind1 < sz);
            assert(ind2 >= 0 && ind2 < sz);
            g[ind1].push_back(ind2);
            g[ind2].push_back(ind1);
        }
        vector<int> used(sz, 0);
        for (int i = 0; i < sz; ++i) {
            if (g[i].size() == 1 && !used[i]) {
                used[i] = 1;
                int v = i;
                while (true) {
                    int u = -1;
                    for (int w : g[v]) {
                        if (!used[w]) {
                            u = w;
                            break;
                        }
                    }
                    if (u == -1) break;
                    used[u] = 1;
                    v = u;
                }
                segs.push_back({pts[i], pts[v]});
            }
        }
        for (int i = 0; i < sz; ++i) {
            assert(used[i]);
        }
    }
//    return 0;
    n = segs.size();
    auto start = segs;
    for (int rot = 1; rot < 8; ++rot) {
        for (auto &seg : segs) {
            seg.first = rot45(seg.first);
            seg.second = rot45(seg.second);
        }
        for (auto &seg : segs) {
            if (seg.first < seg.second) {
                swap(seg.first, seg.second);
            }
        }
        sort(all(segs));
        for (int i = 0; i < n; ++i) {
            for (int z = 0; z < 2; ++z) {
                pt shift = z == 0 ? segs[i].first : segs[i].second;
                shift = shift - start[0].first;
                if (cmp(start, segs, shift)) {
                    cout << rot * 45 << endl;
                    return 0;
                }
            }
        }
    }
    cout << "360\n";
    return 0;
}
