#include <bits/stdc++.h>

using namespace std;

using ll = long long;

enum state {
    UNSET_FALSE_0 = 0,
    SET_TRUE = 1,
    SET_FALSE = 2,
    UNSET_TRUE = 3,
    UNSET_FALSE_1 = 4,
    BAD = 5
};

enum op_type {
    UNSET = 0,
    SET = 1,
};

struct operation {
    bool state;
    op_type type;

    operation() {}
    operation(op_type _t, bool _state) : state(_state), type(_t) {}
};

struct component {
    int idx;
    vector<int> v;

    component(): idx(0) {
        v.clear();
    }

    explicit component(vector<int> _v) : idx(0), v(std::move(_v)) {}
};

int n;
vector<operation> operations;

vector<int> indeg;
vector<vector<int>> graph;
vector<component> components;

void readInput() {
    cin >> n;
    operations.reserve(n);
    for (int i = 0; i < n; ++i) {
        string type, state;
        cin >> type >> state;

        operation cur;
        if (type == "set") {
            cur.type = SET;
        } else {
            cur.type = UNSET;
        }

        if (state == "false") {
            cur.state = false;
        } else {
            cur.state = true;
        }

        operations.push_back(cur);
    }
}

void readGraph() {
    graph.resize(n);
    indeg.resize(n);

    int m;
    cin >> m;
    for (int i = 0; i < m; ++i) {
        int x, y;
        cin >> x >> y;
        --x, --y;

        indeg[y]++;
        graph[x].push_back(y);
    }
}

void dfs(int cur, vector<int> &comp, vector<char> &used) {
    used[cur] = true;
    for (auto u: graph[cur]) {
        if (!used[u]) {
            dfs(u, comp, used);
        }
    }

    comp.push_back(cur);
}

void fillComponents() {
    vector<char> used(n);

    for (int i = 0; i < n; ++i) {
        if (used[i]) {
            continue;
        }

        if (indeg[i] != 0) {
            continue;
        }

        vector<int> cur_comp;
        dfs(i, cur_comp, used);
        reverse(cur_comp.begin(), cur_comp.end());

        components.emplace_back(cur_comp);
    }
}

queue<component*> unset_false, unset_true, set_true, set_false;

void addToQueue(component* comp) {
    if (comp == nullptr) {
        return;
    }

    int idx = comp->idx;
    if (idx >= comp->v.size()) {
        return;
    }

    operation op = operations[comp->v[idx]];
    if (op.type == UNSET) {
        if (op.state == false) {
            unset_false.push(comp);
        } else if (op.state == true) {
            unset_true.push(comp);
        }
    } else {
        if (op.state == false) {
            set_false.push(comp);
        } else if (op.state == true) {
            set_true.push(comp);
        }
    }
}

state getNextState(state cur) {
    if (cur == UNSET_FALSE_0) {

        return SET_TRUE;
    } else if (cur == SET_TRUE) {

        return SET_FALSE;
    } else if (cur == SET_FALSE) {

        return UNSET_TRUE;
    } else if (cur == UNSET_TRUE) {

        return UNSET_FALSE_1;
    } else {

        return BAD;
    }
}

void initComponents() {
    for (int i = 0; i < components.size(); ++i) {
        const auto &comp = components[i];
        addToQueue(&components[i]);
    }
}

int getOperation(queue<component*> &q) {
    if (q.empty()) {
        return -1;
    }

    auto top = q.front();
    q.pop();

    int res = top->v[top->idx];

    top->idx++;
    addToQueue(top);

    return res;
}

void solve() {
    readInput();
    readGraph();
    fillComponents();
    initComponents();

    state cur = UNSET_FALSE_0;
    vector<int> ans;
    while (cur != BAD) {
        int op = -1;
        switch (cur) {
            case UNSET_FALSE_0:
                op = getOperation(unset_false);
                break;
            case SET_TRUE:
                op = getOperation(set_true);
                break;
            case SET_FALSE:
                op = getOperation(set_false);
                break;
            case UNSET_TRUE:
                op = getOperation(unset_true);
                break;
            case UNSET_FALSE_1:
                op = getOperation(unset_false);
                break;
            case BAD:
                op = -1;
                break;
        }

        if (op == -1) {
            cur = getNextState(cur);
        } else {
            ans.push_back(op);
        }
    }

    if (!unset_false.empty() || !unset_true.empty() || !set_false.empty() || !set_true.empty()) {
        cout << -1 << endl;
    } else {
        assert(ans.size() == operations.size());

        bool check = true;
        bool was_set_true = false;
        bool was_unset_true = false;
        for (int i = 0; i < n && check; ++i) {
            const auto &op = operations[ans[i]];
            if (op.type == SET && op.state == true) {
                was_set_true = true;
            }
            if (op.type == UNSET && op.state == true) {
                was_unset_true = true;
            }

            if (op.type == SET && op.state == false) {
                if (!was_set_true) {
                    check = false;
                }
            }

            if (op.type == UNSET && op.state == false && was_set_true) {
                if (!was_unset_true) {
                    check = false;
                }
            }
        }

        if (!check) {
            cout << -1 << endl;
            return;
        }

        for (int i = 0; i < n; ++i) {
            cout << ans[i] + 1 << " ";
        }
        cout << endl;
    }

}

int main() {
    cin.tie(nullptr);
    cout.tie(nullptr);
    ios_base::sync_with_stdio(false);

    int t = 1;
    // cin >> t;
    while (t--) {
        solve();
    }
    cout.flush();
}
