#include <iostream>
#include <vector>
#include <deque>
#include <set>
#include <cstdint>

#define int int64_t

using namespace std;

struct Edge {
    int to, weight;
    Edge() = default;
    Edge(int to_, int weight_) : to(to_), weight(weight_) {}
};

using Graph = vector<vector<Edge>>;

signed main() {
    int n, m; cin >> n >> m;
    Graph graph(n);
    for (int i = 0; i < m; i++) {
        int v, u; cin >> v >> u; v--; u--;
        int w; cin >> w;
        // WARNING ONLY INVERSE GRAPH NEEDED
        graph[u].emplace_back(v, w);
    }
    vector<bool> is_reachable(n, false);
    deque<int> vertices;

    // cerr << "CUM" << endl;

    // BFS reachable
    vertices = {n - 1};
    is_reachable[n - 1] = true;
    while (!vertices.empty()) {
        int v = vertices.front();
        vertices.pop_front();
        for (auto [u, w] : graph[v]) {
            if (!is_reachable[u]) {
                is_reachable[u] = true;
                vertices.push_back(u);
            }
        }
    }

    
    // cerr << "CUM" << endl;

    if (!is_reachable[0]) {
        cout << -1 << endl;
        return 0;
    }

    vector<int> dist_to_unreachable(n, n + 228);

    // BFS dist to unreachable
    vertices.clear();
    for (int i = 0; i < n - 1; i++) {
        if (!is_reachable[i]) {
            vertices.push_back(i);
            dist_to_unreachable[i] = 0;
        }
    }

    while (!vertices.empty()) {
        int v = vertices.front();
        vertices.pop_front();
        for (auto [u, w] : graph[v]) {
            if (u == n - 1) continue;
            if (dist_to_unreachable[v] + 1 < dist_to_unreachable[u]) {
                dist_to_unreachable[u] = dist_to_unreachable[v] + 1;
                vertices.push_back(u);
            }
        }
    }

    // cerr << "CUM" << endl;

    // for (int i = 0; i < n; i++) {
    //     cerr << i << ' ' << dist_to_unreachable[i] << endl;
    // }

    auto add_edge = [&](pair<int64_t, int> path_weight, const Edge &e) -> pair<int64_t, int>{
        return make_pair(path_weight.first + e.weight, max(path_weight.second, -dist_to_unreachable[e.to]));
    };

    vector<pair<int64_t, int>> distances(n, make_pair(1LL << 60, -n - 228));
    distances[n - 1] = make_pair(0, -n - 228);

    auto cmp = [&distances](int i, int j) {
        return make_pair(distances[i], i) < make_pair(distances[j], j);
    };

    set<int, decltype(cmp)> vertices_set(cmp);
    for (int i = 0; i < n; i++) {
        vertices_set.insert(i);
    }
    while (!vertices_set.empty()) {
        int v = *vertices_set.begin();
        // cerr << "POP " << v << endl;
        vertices_set.erase(v);
        for (const Edge &e : graph[v]) {
            pair<int64_t, int> new_weight = add_edge(distances[v], e);
            if (new_weight < distances[e.to]) {
                vertices_set.erase(e.to);
                distances[e.to] = new_weight;
                vertices_set.insert(e.to);
            }
        }
    }
    int ans = -distances[0].second;
    if (ans > n + 1) ans = n + 1;
    cout << ans - 1 << endl;
}