#include <bits/stdc++.h>
using namespace std;

struct Point {
    int32_t x;
    int32_t x_sq2;
    int32_t y;
    int32_t y_sq2;

    Point& operator+=(const Point& other) {
        x += other.x;
        x_sq2 += other.x_sq2;
        y += other.y;
        y_sq2 += other.y_sq2;
        return *this;
    }

    Point& operator-=(const Point& other) {
        x -= other.x;
        x_sq2 -= other.x_sq2;
        y -= other.y;
        y_sq2 -= other.y_sq2;
        return *this;
    }

    Point operator+(const Point& other) {
        return {x + other.x, x_sq2 + other.x_sq2, y + other.y, y_sq2 + other.y_sq2};
    }

    Point operator-(const Point& other) {
        return {x - other.x, x_sq2 - other.x_sq2, y - other.y, y_sq2 - other.y_sq2};
    }

    Point operator*(int32_t d) {
        return {x * d, x_sq2 * d, y * d, y_sq2 * d};
    }

    bool operator<(const Point& other) const {
        return std::tie(x, x_sq2, y, y_sq2) < std::tie(other.x, other.x_sq2, other.y, other.y_sq2);
    }

    bool operator==(const Point& other) const {
        return std::tie(x, x_sq2, y, y_sq2) == std::tie(other.x, other.x_sq2, other.y, other.y_sq2);
    }

    Point normalize() {
        int32_t max_abs = 0;
        max_abs = std::max(max_abs, std::abs(x));
        max_abs = std::max(max_abs, std::abs(x_sq2));
        max_abs = std::max(max_abs, std::abs(y));
        max_abs = std::max(max_abs, std::abs(y_sq2));
        return {x / max_abs, x_sq2 / max_abs, y / max_abs, y_sq2 / max_abs};
    }
};

struct Action {
    int32_t type;
    int32_t d;
    int32_t angle;
};

int32_t main() {
    std::ios_base::sync_with_stdio(false);
    std::cin.tie(nullptr);

    int32_t n;
    std::cin >> n;

    std::vector<Action> arr(n);
    for (int32_t i = 0; i < n; i++) {
        std::string type;
        int32_t val;
        std::cin >> type >> val;

        if (type == "draw") {
            arr[i] = {1, val, 0};
        } else if (type == "move") {
            arr[i] = {2, val, 0};
        } else
            arr[i] = {0, 0, val};
    }

    Point dirs[8] = {{0, 0, -1, 0},
                     {0, 1, 0, -1},
                     {1, 0, 0, 0},
                     {0, 1, 0, 1},
                     {0, 0, 1, 0},
                     {0, -1, 0, 1},
                     {-1, 0, 0, 0},
                     {0, -1, 0, -1}};

    std::vector<std::pair<Point, Point>> segments;
    Point first_p;
    int32_t first_angle, to_do;

    Point p = {0, 0};
    int32_t angle = 0;
    for (int32_t i = 0; i < n; i++) {
        if (arr[i].type == 0) {
            angle += arr[i].angle;
            angle %= 360;
        } else if (arr[i].type == 1) {
            if (segments.empty()) {
                first_p = p;
                first_angle = angle;
                to_do = i - 1;
            }
            segments.emplace_back(p, p + dirs[angle / 45] * arr[i].d);
            if (segments.back().second < segments.back().first)
                std::swap(segments.back().first, segments.back().second);
            p += dirs[angle / 45] * arr[i].d;
        } else {
            p += dirs[angle / 45] * arr[i].d;
        }
    }

    auto src_segments = segments;
    std::sort(src_segments.begin(), src_segments.end());
    int32_t old_size = segments.size();
    for (int32_t i = 0; i < old_size; i++)
        segments.emplace_back(segments[i].second, segments[i].first);

    int32_t ans = 360;
    for (int32_t j = 0; j < segments.size(); j++) {
        p = segments[j].first;
        for (int32_t i = 0; i < 8; i++)
            if (dirs[i] == (segments[j].second - segments[j].first).normalize())
                angle = 45 * i;

        for (int32_t i = to_do; i >= 0; i--) {
            if (arr[i].type == 0) {
                angle = (angle - arr[i].angle + 360) / 360;
                angle %= 360;
            } else if (arr[i].type == 1) {
                p -= dirs[angle / 45] * arr[i].d;
            } else {
                p -= dirs[angle / 45] * arr[i].d;
            }
        }
        int32_t src_angle = angle;

        std::vector<std::pair<Point, Point>> segments2;
        for (int32_t i = 0; i < n; i++) {
            if (arr[i].type == 0) {
                angle += arr[i].angle;
                angle %= 360;
            } else if (arr[i].type == 1) {
                segments2.emplace_back(p, p + dirs[angle / 45] * arr[i].d);
                if (segments2.back().second < segments2.back().first)
                    std::swap(segments2.back().first, segments2.back().second);
                p += dirs[angle / 45] * arr[i].d;
            } else {
                p += dirs[angle / 45] * arr[i].d;
            }
        }

        std::sort(segments2.begin(), segments2.end());
        bool good = true;
        for (int32_t i = 0; i < src_segments.size(); i++)
            if (src_segments[i] != segments2[i])
                good = false;
        if (good)
            ans = std::min(ans, (src_angle == 0) ? 360 : src_angle);
    }

    std::cout << ans << std::endl;
}